import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-fbb42d30.js';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { inject } from '@ember/service';

var _class, _descriptor;

/**
 * Ask component
 *
 * Usage:
 *
 * #### Handlebars
 * ```hbs
 * <Ask @title="Where is Padmé?" @question="Is she safe? Is she all right?" @answer="It seems, in your anger, you killed her." @okBtnText="Answer" @cancelBtnText="Cancel" @okClick={{fn this.showAlert "Message"}} @cancelClick={{fn this.showAlert "Message"}} />
 * ```
 * #### JavaScript
 * ```js
 * this.notiflix.ask(title, question, answer, okBtnText, cancelBtnText, okClick, cancelClick);
 * ```
 * @class Ask
 * @public
 */
let AskComponent = (_class = class AskComponent extends Component {
  /**
   * Title of the question
   *
   * @argument title
   * @type string
   */
  get title() {
    return this.args.title || '';
  }
  /**
   * Question to show
   *
   * @argument question
   * @type string
   */
  get question() {
    return this.args.question || '';
  }
  /**
   * Answer to show
   *
   * @argument answer
   * @type string
   */
  get answer() {
    return this.args.answer || '';
  }
  /**
   * OK button text
   *
   * @argument okBtnText
   * @type string
   */
  get okBtnText() {
    return this.args.okBtnText || '';
  }
  /**
   * Cancel button text
   *
   * @argument cancelBtnText
   * @type string
   */
  get cancelBtnText() {
    return this.args.cancelBtnText || '';
  }
  /**
   * OK click callback
   *
   * @argument okClick
   * @type function
   */
  get okClick() {
    return this.args.okClick;
  }
  /**
   * Cancel click callback
   *
   * @argument cancelClick
   * @type function
   */
  get cancelClick() {
    return this.args.cancelClick;
  }
  /**
   * Options to merge
   *
   * @argument options
   * @type object
   */
  get options() {
    return this.args.options;
  }
  constructor() {
    super(...arguments);
    /**
     * Injected Notiflix service
     *
     * @property notiflix
     * @type Notiflix
     */
    _initializerDefineProperty(this, "notiflix", _descriptor, this);
    this._displayAsk();
  }
  _displayAsk() {
    if (this.options) {
      this.notiflix._confirmMerge(this.options);
    }
    this.notiflix.ask(this.title, this.question, this.answer, this.okBtnText, this.cancelBtnText, this.okClick, this.cancelClick);
  }
}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "notiflix", [inject], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "title", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "title"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "question", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "question"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "answer", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "answer"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "okBtnText", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "okBtnText"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "cancelBtnText", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "cancelBtnText"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "okClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "okClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "cancelClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "cancelClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype)), _class);

export { AskComponent as default };
//# sourceMappingURL=ask.js.map
