import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-fbb42d30.js';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { inject } from '@ember/service';
import { set } from '@ember/object';

var _class, _descriptor;

/**
 * Block component
 *
 * Usage:
 *
 * #### Handlebars
 * ```hbs
 * <Block @type="standard" @elements="li.items" @message="Loading..." />
 * ```
 * #### JavaScript
 * ```js
 * this.notiflix.block(type, elements, message);
 * ```
 * @class Block
 * @public
 */
let BlockComponent = (_class = class BlockComponent extends Component {
  /**
   * Type of block screen
   *
   * Values: standard | hourglass | circle | arrows | dots | pulse
   *
   * Default: standard
   *
   * @argument type
   * @type string
   */
  get type() {
    return this.args.type || this._type;
  }
  /**
   * Elements to block. (ID or Class)
   *
   * @argument elements
   * @type string
   */
  get elements() {
    return this.args.elements || '';
  }
  /**
   * Message to show
   *
   * @argument message
   * @type string
   */
  get message() {
    return this.args.message || '';
  }
  /**
   * Options to merge
   *
   * @argument options
   * @type object
   */
  get options() {
    return this.args.options;
  }
  constructor() {
    super(...arguments);
    /**
     * Injected Notiflix service
     *
     * @property notiflix
     * @type ember/service
     */
    _initializerDefineProperty(this, "notiflix", _descriptor, this);
    set(this, '_type', arguments[2] || 'standard');
    this._displayBlock();
  }
  _displayBlock() {
    if (this.options) {
      this.notiflix._blockMerge(this.options);
    }
    this.notiflix.block(this.type, this.elements, this.message);
  }

  /**
   * To remove block immediately or after delay time (milliseconds)
   *
   * @method remove
   * @param {string} element
   * @param {number} delay, optional
   */
  remove(elements, delay) {
    this.notiflix.blockRemove(elements, delay);
  }
}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "notiflix", [inject], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "type", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "type"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "elements", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "elements"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "message", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "message"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype)), _class);

export { BlockComponent as default };
//# sourceMappingURL=block.js.map
