import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-fbb42d30.js';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { inject } from '@ember/service';

var _class, _descriptor;

/**
 * Confirm component
 *
 * Usage:
 *
 * #### Handlebars
 * ```hbs
 * <Confirm @title="Notiflix Confirm" @message="Do you agree with me?" @okBtnText="Yes" @cancelBtnText="No" @okClick={{fn this.showAlert "Message"}} @cancelClick={{fn this.showAlert "Message"}} />
 * ```
 * #### JavaScript
 * ```js
 * this.notiflix.confirm(title, message, okBtnText, cancelBtnText, okClick, cancelClick);
 * ```
 * @class Confirm
 * @public
 */
let ConfirmComponent = (_class = class ConfirmComponent extends Component {
  /**
   * Title of the confirm
   *
   * @argument title
   * @type string
   */
  get title() {
    return this.args.title || '';
  }
  /**
   * Message to show
   *
   * @argument message
   * @type string
   */
  get message() {
    return this.args.message || '';
  }
  /**
   * OK button text
   *
   * @argument okBtnText
   * @type string
   */
  get okBtnText() {
    return this.args.okBtnText || '';
  }
  /**
   * Cancel button text
   *
   * @argument cancelBtnText
   * @type string
   */
  get cancelBtnText() {
    return this.args.cancelBtnText || '';
  }
  /**
   * OK click callback
   *
   * @argument okClick
   * @type function
   */
  get okClick() {
    return this.args.okClick;
  }
  /**
   * Cancel click callback
   *
   * @argument cancelClick
   * @type function
   */
  get cancelClick() {
    return this.args.cancelClick;
  }
  /**
   * Options to merge
   *
   * @argument options
   * @type object
   */
  get options() {
    return this.args.options;
  }
  constructor() {
    super(...arguments);
    /**
     * Injected Notiflix service
     *
     * @property notiflix
     * @type Notiflix
     */
    _initializerDefineProperty(this, "notiflix", _descriptor, this);
    this._displayConfirm();
  }
  _displayConfirm() {
    if (this.options) {
      this.notiflix._confirmMerge(this.options);
    }
    this.notiflix.confirm(this.title, this.message, this.okBtnText, this.cancelBtnText, this.okClick, this.cancelClick);
  }
}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "notiflix", [inject], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "title", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "title"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "message", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "message"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "okBtnText", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "okBtnText"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "cancelBtnText", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "cancelBtnText"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "okClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "okClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "cancelClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "cancelClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype)), _class);

export { ConfirmComponent as default };
//# sourceMappingURL=confirm.js.map
