import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-fbb42d30.js';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { inject } from '@ember/service';
import { set } from '@ember/object';

var _class, _descriptor;

/**
 * Notify component
 *
 * Usage:
 *
 * #### Handlebars
 * ```hbs
 * <Notify @type="success" @message="Success" @onClick={{fn this.showAlert "Message"}} />
 * ```
 * #### JavaScript
 * ```js
 * this.notiflix.notify(type, message, callback);
 * ```
 * @class Notify
 * @public
 */
let NotifyComponent = (_class = class NotifyComponent extends Component {
  /**
   * Type of notify
   *
   * Values: success | failure | warning | info
   *
   * Default: success
   *
   * @argument type
   * @type string
   */
  get type() {
    return this.args.type || this._type;
  }
  /**
   * Message to show
   *
   * @argument message
   * @type string
   */
  get message() {
    return this.args.message || '';
  }
  /**
   * onClick callback
   *
   * @argument onClick
   * @type function
   */
  get onClick() {
    return this.args.onClick;
  }
  /**
   * Options to merge
   *
   * @argument options
   * @type object
   */
  get options() {
    return this.args.options;
  }
  constructor() {
    super(...arguments);
    /**
     * Injected Notiflix service
     *
     * @property notiflix
     * @type ember/service
     */
    _initializerDefineProperty(this, "notiflix", _descriptor, this);
    set(this, '_type', arguments[2] || 'success');
    this._displayNotify();
  }
  _displayNotify() {
    if (this.options) {
      this.notiflix._notifyMerge(this.options);
    }
    this.notiflix.notify(this.type, this.message, this.onClick);
  }
}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "notiflix", [inject], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "type", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "type"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "message", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "message"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "onClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "onClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype)), _class);

export { NotifyComponent as default };
//# sourceMappingURL=notify.js.map
