import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-fbb42d30.js';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { inject } from '@ember/service';
import { set } from '@ember/object';

var _class, _descriptor;

/**
 * Report component
 *
 * Usage:
 *
 * #### Handlebars
 * ```hbs
 * <Report @type="success" @title="Success" @message="Message" @btnText="OK" @onClick={{fn this.showAlert "Message"}} />
 * ```
 * #### JavaScript
 * ```js
 * this.notiflix.report(type, title, message, btnText, callback);
 * ```
 * @class Report
 * @public
 */
let ReportComponent = (_class = class ReportComponent extends Component {
  /**
   * Type of report
   *
   * Values: success | failure | warning | info
   *
   * Default: success
   *
   * @argument type
   * @type string
   */
  get type() {
    return this.args.type || this._type;
  }
  /**
   * Title of the report
   *
   * @argument title
   * @type string
   */
  get title() {
    return this.args.title || '';
  }
  /**
   * Message to show
   *
   * @argument message
   * @type string
   */
  get message() {
    return this.args.message || '';
  }
  /**
   * Button text to close report
   *
   * Default: OK
   *
   * @argument btnText
   * @type string
   */
  get btnText() {
    return this.args.btnText || 'OK';
  }
  /**
   * onClick callback
   *
   * @argument onClick
   * @type function
   */
  get onClick() {
    return this.args.onClick;
  }
  /**
   * Options to merge
   *
   * @argument options
   * @type object
   */
  get options() {
    return this.args.options;
  }
  constructor() {
    super(...arguments);
    /**
     * Injected Notiflix service
     *
     * @property notiflix
     * @type ember/service
     */
    _initializerDefineProperty(this, "notiflix", _descriptor, this);
    set(this, '_type', arguments[2] || 'success');
    this._displayReport();
  }
  _displayReport() {
    if (this.options) {
      this.notiflix._reportMerge(this.options);
    }
    this.notiflix.report(this.type, this.title, this.message, this.btnText, this.onClick);
  }
}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "notiflix", [inject], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "type", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "type"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "title", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "title"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "message", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "message"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "btnText", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "btnText"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "onClick", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "onClick"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype)), _class);

export { ReportComponent as default };
//# sourceMappingURL=report.js.map
